@@ -1,8 +1,8 @@
 modEvAmethods <- function(fun) {
-  # version 1.5 (10 Nov 2023)
+  # version 1.6 (25 Mar 2024)
 
   if (fun %in% c("threshMeasures", "multModEv")) {
-    thresh.measures <- c("CCR", "Misclass", "Sensitivity", "Specificity", "Omission", "Commission", "Precision", "Recall", "PPP", "NPP", "UPR", "OPR", "PPI", "PAI", "kappa", "TSS", "NMI", "F1score", "OddsRatio")
+    thresh.measures <- c("CCR", "Misclass", "Sensitivity", "Specificity", "Omission", "Commission", "Precision", "Recall", "PPP", "NPP", "UPR", "OPR", "PPI", "PAI", "kappa", "TSS", "NMI", "F1score", "OddsRatio", "ORSS", "SEDI")
 
     if (fun == "threshMeasures") return(thresh.measures)
 
